@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -605,8 +603,8 @@ ADD_TES_FAILURE:
 	
 	
 	require_nonzero_quiet ( fTimerEvent, TIMER_CREATION_FAILURE );
-	fDispatchEvent->release ( );
-	fDispatchEvent = NULL;
+	fTimerEvent->release ( );
+	fTimerEvent = NULL;
 	
 	
 TIMER_CREATION_FAILURE:
@@ -1073,6 +1071,18 @@ IOSCSIParallelInterfaceController::DisableInterrupt ( void )
 }
 
 
+//
+//	SignalInterrupt - Cause the work loop to schedule the interrupt action
+//					  even if the filter routine returns false.		[PROTECTED]
+//
+
+void
+IOSCSIParallelInterfaceController::SignalInterrupt ( void )
+{
+	( ( IOFilterInterruptEventSource * ) fDispatchEvent )->signalInterrupt ( );
+}
+
+
 #if 0
 #pragma mark -
 #pragma mark Timeout Management
