@@ -3,8 +3,6 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
- * 
  * This file contains Original Code and/or Modifications of Original Code
  * as defined in and that are subject to the Apple Public Source License
  * Version 2.0 (the 'License'). You may not use this file except in
@@ -42,7 +40,7 @@
 #include <IOKit/scsi/IOSCSIProtocolServices.h>
 
 // SCSI Parallel Family Headers
-#include <IOKit/scsi/spi/IOSCSIParallelInterfaceController.h>
+#include "IOSCSIParallelInterfaceController.h"
 #include "SCSIParallelTask.h"
 
 
@@ -597,7 +595,7 @@ public:
 	 */
 	bool		start ( IOService * provider );
 	void		stop ( IOService *  provider );
-
+	void		free ( void );
 	bool		willTerminate ( IOService * provider, IOOptionBits options );
 	bool		didTerminate ( IOService * provider, IOOptionBits options, bool * defer );	
 	
